@@ -1,6 +1,6 @@
-from abstract_solcatcher.utils import get_async_response,getEndpointUrl,get_headers
-from abstract_solcatcher.async_utils import asyncPostRequest
-import json,requests
+from ..utils import get_async_response,getEndpointUrl,get_headers
+from ..async_utils import asyncPostRequest
+import json,requests,base58
 from ..abstract_rate_limit import makeLimitedCall
 from solana.rpc.types import TxOpts
 from solana.transaction import Transaction
@@ -29,11 +29,11 @@ def getTokenAccountBalance(account,mint=None,commitment=None):
 def getTokenAccountsByOwner(account,mint=None,encoding=None):
   return get_async_response(get_solcatcher_endpoint,endpoint="getTokenAccountsByOwner",account=account,mint=mint,encoding=encoding)
 
-def getMetaData(address):
-  return get_async_response(get_solcatcher_endpoint,endpoint="getMetaData",address=address)
+def getMetaData(mint):
+  return get_async_response(get_solcatcher_endpoint,endpoint="getMetaData",mint=mint)
 
-def getTransaction(signature,maxSupportedTransactionVersion=None):
-  return get_async_response(get_solcatcher_endpoint,endpoint="getTransaction",signature=signature,maxSupportedTransactionVersion=maxSupportedTransactionVersion)
+def getTransaction(signature=None,commitment=None,maxSupportedTransactionVersion=None):
+  return get_async_response(get_solcatcher_endpoint,endpoint="getTransaction",signature=signature,commitment=commitment,maxSupportedTransactionVersion=maxSupportedTransactionVersion)
 
 def getLatestBlockHash(commitment=None):
     return get_async_response(get_solcatcher_endpoint,endpoint="getLatestBlockhash",commitment=commitment)
@@ -44,6 +44,25 @@ def getAccountInfo(account,encoding=None,commitment=None):
 def getBlock(slot,encoding=None,maxSupportedTransactionVersion=None,transactionDetails= None,rewards=None):
     return get_async_response(get_solcatcher_endpoint,endpoint="getBlock",slot=slot,encoding=encoding,maxSupportedTransactionVersion=maxSupportedTransactionVersion,transactionDetails=transactionDetails,rewards=rewards)
 
+def getParsedTransaction(signature=None,txnData=None,programId=None,encoding=None,commitment=None,maxSupportedTransactionVersion=None):
+    return get_async_response(get_solcatcher_endpoint,endpoint="getParsedTransaction",signature=signature,txnData=txnData,programId=programId,encoding=encoding,commitment=commitment,maxSupportedTransactionVersion=maxSupportedTransactionVersion)
+
+def quickBuyData(mint=None):
+    return get_async_response(get_solcatcher_endpoint,endpoint="dbSearch",tableName="quickbuydata",searchValue=mint)
+
+def getTxLog(signature=None):
+    return get_async_response(get_solcatcher_endpoint,endpoint="getTxLog",signature=signature)
+
+def insertTxLog(txLog,signature=None):
+    return get_async_response(get_solcatcher_endpoint,endpoint="insertTxLog",txLogs=txnLog,signature=signature)
+
+async def bulkInsertTxnLogs_async(txnLogs):
+    for txLog in txLogs:
+        await asyncPostRequest(url=getEndpointUrl("insertTxLog"),data={"txLog":txLog,"signature":get_any_value(txLog,"signature")},headers=get_headers())
+
+def bulkInsertTxnLogs(txLogs):
+    return get_async_response(bulkInsertTxnLogs_async,txLogs=txnLogs,signature=signature)
+
 def sendTransaction(txn: Transaction, payer_keypair, opts=None,skip_preflight=None) -> dict:
     skip_preflight = skip_preflight or True
     opts = opts or TxOpts(skip_preflight=skip_preflight)
